# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorarch: %global perl_vendorarch %(eval "`perl -V:installvendorarch`"; echo $installvendorarch)}

# BAIL_OUT introduced in Test::More 0.60_01, which we'll call 0.61
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.61) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Net-SSLeay
Version:	1.45
Release:	1.0.cf.%{__distinit}%{__distvers}
Summary:	Perl extension for using OpenSSL
Group:		Development/Libraries
License:	OpenSSL
URL:		http://search.cpan.org/dist/Net-SSLeay/
Source0:	http://search.cpan.org/CPAN/authors/id/M/MI/MIKEM/Net-SSLeay-%{version}.tar.gz
Patch0:		Net-SSLeay-1.43-old-Test::More.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	openssl-devel, krb5-devel, zlib-devel, pkgconfig
BuildRequires:	perl(Carp)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(MIME::Base64)
BuildRequires:	perl(Test::Exception)
# Test::Kwalitee => Module::CPANTS::Analyze => Net::HTTP => IO::Socket::SSL => Net::SSLeay
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Test::Kwalitee)
%endif
BuildRequires:	perl(Test::NoWarnings)
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Pod::Coverage)
BuildRequires:	perl(Test::Warn)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

# Don't "provide" private Perl libs or the redundant unversioned perl(Net::SSLeay) provide
%global __provides_exclude ^(perl\\(Net::SSLeay\\)$|SSLeay\\.so)

%description
This module offers some high level convenience functions for accessing
web pages on SSL servers (for symmetry, same API is offered for
accessing http servers, too), a sslcat() function for writing your own
clients, and finally access to the SSL API of SSLeay/OpenSSL package
so you can write servers or clients for more complicated applications.

%prep
%setup -q -n Net-SSLeay-%{version}

# Fix permissions and shellbangs in examples
# to avoid bogus doc-file dependencies
chmod -c 644 examples/*
perl -pi -e 's|/usr/local/bin/perl|/usr/bin/perl|' examples/*.pl

# If we have a Test::More without BAIL_OUT, patch the test suite to provide it
%if %{old_test_more}
%patch0 -p1
%endif

# Remove redundant unversioned provide if we don't have rpm 4.9 or later
%global provfilt /bin/sh -c "%{__perl_provides} | grep -Fvx 'perl(Net::SSLeay)'"
%define __perl_provides %{provfilt}

%build
PERL_MM_USE_DEFAULT=1 perl Makefile.PL \
	INSTALLDIRS=vendor \
	INC="$(pkg-config --cflags-only-I openssl)" \
	LIBS="$(pkg-config --libs openssl)" \
	OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name '*.bs' -empty -exec rm -f {} ';'
chmod -R u+w %{buildroot}

# Remove script we don't want packaged
rm -f %{buildroot}%{perl_vendorarch}/Net/ptrtstrun.pl

%check
make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes Credits QuickRef README examples/ TODO
%{perl_vendorarch}/auto/Net/
%dir %{perl_vendorarch}/Net/
%{perl_vendorarch}/Net/SSLeay/
%{perl_vendorarch}/Net/SSLeay.pm
%doc %{perl_vendorarch}/Net/SSLeay.pod
%{_mandir}/man3/Net::SSLeay.3pm*
%{_mandir}/man3/Net::SSLeay::Handle.3pm*

%changelog
* Sat Feb 25 2012 Paul Howarth <paul@city-fan.org> - 1.45-1.0.cf
- update to 1.45
  - added missing t/data/binary-test.file to MANIFEST (CPAN RT#75261)
  - added mising documentation for SESSION_cmp (CPAN RT#75264)

* Fri Feb 24 2012 Paul Howarth <paul@city-fan.org> - 1.43-1.0.cf
- update to 1.43 (see Changes file for full details)
  - added thread safety and dynamic locking, which should complete thread
    safety work, making Net::SSLeay completely thread-safe
  - lots of improved documentation
- BR: perl(Test::Pod::Coverage)
- install Net/SSLeay.pod as %%doc
- include binary-test.file from upstream svn, missing from tarball
  (CPAN RT#75261)
- patch Net::SSLeay.pod to document function SESSION_cmp, only included with
  openssl < 1 (CPAN RT#75264)
- add patch to work around Test::More::BAIL_OUT not being available with old
  versions of Test::More

* Mon Oct  3 2011 Paul Howarth <paul@city-fan.org> - 1.42-1.0.cf
- update to 1.42
  - fixed incorrect documentation of how to enable CRL checking
  - fixed incorrect letter in Sebastien in Credits
  - changed order of the Changes file to be reverse chronological
  - fixed a compile error when building on Windows with MSVC6
- drop UTF8 patch, no longer needed

* Sun Sep 25 2011 Paul Howarth <paul@city-fan.org> - 1.41-1.0.cf
- update to 1.41
  - fixed incorrect const signatures for 1.0 that were causing warnings; now
    have clean compile with 0.9.8a through 1.0.0
- BR: perl(Carp)

* Fri Sep 23 2011 Paul Howarth <paul@city-fan.org> - 1.40-1.0.cf
- update to 1.40
  - fixed incorrect argument type in call to SSL_set1_param
  - fixed a number of issues with pointer sizes; removed redundant pointer cast
    tests from t/
  - added Perl version requirements to SSLeay.pm

* Wed Sep 21 2011 Paul Howarth <paul@city-fan.org> - 1.39-1.0.cf
- update to 1.39
  - downgraded Module::Install to 0.93 since 1.01 was causing problems in the
    Makefile

* Fri Sep 16 2011 Paul Howarth <paul@city-fan.org> - 1.38-1.0.cf
- update to 1.38
  - fixed a problem with various symbols that only became available in OpenSSL
    0.9.8 such as X509_VERIFY_PARAM and X509_POLICY_NODE, causing build
    failures with older versions of OpenSSL (CPAN RT#71013)
- drop upstreamed patch for building with OpenSSL < 0.9.8 (CPAN RT#71013)

* Fri Sep 16 2011 Paul Howarth <paul@city-fan.org> - 1.37-1.0.cf
- update to 1.37
  - added X509_get_fingerprint
  - added support for SSL_CTX_set1_param, SSL_set1_param and selected
    X509_VERIFY_PARAM_* OBJ_* functions
  - fixed the prototype for randomize()
  - fixed an uninitialized value warning in $Net::SSLeay::proxyauth
  - allow net-ssleay to compile if SSLV2 is not present
  - fixed a problem where sslcat (and possibly other functions) expect RSA
    keys and will not load DSA keys for client certificates
  - removed SSL_CTX_v2_new and SSLv2_method() for OpenSSL 1.0 and later
  - added CTX_use_PKCS12_file
- this release by MIKEM => update source URL
- add patch to support building with OpenSSL < 0.9.8 (CPAN RT#71013)

* Wed Jul 13 2011 Paul Howarth <paul@city-fan.org> - 1.36-5.0.cf
- rebuild for perl 5.14.1 in Rawhide

* Mon Jun 27 2011 Paul Howarth <paul@city-fan.org> - 1.36-4.0.cf
- use a patch rather than a scripted iconv to fix the character encoding
- BR: perl(Test::Kwalitee) unless we're bootstrapping
- drop redundant buildreqs perl(Array::Compare), perl(Sub::Uplevel) and
  perl(Tree::DAG_Node)
- modernize provides filter
- nobody else likes macros for commands
- fix dist tag for CentOS 6 and Scientific Linux

* Fri Jun 25 2010 Paul Howarth <paul@city-fan.org> - 1.36-2.1.cf
- rebuild for perl 5.12.1 in Rawhide

* Thu Jun  3 2010 Paul Howarth <paul@city-fan.org> - 1.36-2.0.cf
- fix dist tag for RHEL-6 Beta

* Sun Jan 31 2010 Paul Howarth <paul@city-fan.org> - 1.36-1.0.cf
- update to 1.36 (see Changes for details)
- drop svn patches

* Mon Aug 24 2009 Paul Howarth <paul@city-fan.org> - 1.35-4.0.cf
- update to svn trunk (rev 253), upstream fix for EVP_sha256 issue

* Sat Aug 22 2009 Paul Howarth <paul@city-fan.org> - 1.35-3.0.cf
- update to svn trunk (rev 252), needed due to omission of MD2 functionality
  from OpenSSL 1.0.0 (CPAN RT#48916)
- define OPENSSL_NO_SHA256 manually if we have openssl < 0.9.8 to prevent build
  failures due to missing symbol EVP_sha256 in older openssl versions

* Mon Mar  2 2009 Paul Howarth <paul@city-fan.org> - 1.35-2.0.cf
- filter out unwanted provides for perl shared objects
- update to SLES-compatible dist tag macros

* Wed Feb  4 2009 Paul Howarth <paul@city-fan.org> - 1.35-1.1.cf
- rebuild for new openssl on Rawhide

* Mon Jul 28 2008 Paul Howarth <paul@city-fan.org> - 1.35-1.0.cf
- update to 1.35
- tweak dist tag macros to work on current Rawhide with three-part releasenum
- drop flag and patch for enabling/disabling external tests - patch now upstream
- external hosts patch no longer needed as we don't do external tests
- drop unused VERBOSE=1 parameter from Makefile.PL invocation
- filter out unversioned provide for perl(Net::SSLeay)

* Tue Mar 11 2008 Paul Howarth <paul@city-fan.org> - 1.32-5.0.cf
- rebuild for perl 5.10.0 in Fedora 9

* Fri Dec  7 2007 Paul Howarth <paul@city-fan.org> - 1.32-3
- rebuild for new openssl in Rawhide

* Fri Nov 30 2007 Paul Howarth <paul@city-fan.org> - 1.32-2
- import from Fedora
- add buildreqs krb5-devel, zlib-devel, and pkgconfig, missing deps of
  openssl-devel in some old distributions
- help the compiler/linker find files/libs by setting INC/LIBS

* Wed Nov 28 2007 Paul Howarth <paul@city-fan.org> - 1.32-1
- update to 1.32, incorporate new upstream URLs
- cosmetic spec changes suiting new maintainer's preferences
- fix argument order for find with -depth
- remove patch for CVE-2005-0106, fixed upstream in 1.30 (#191351)
  (http://rt.cpan.org/Public/Bug/Display.html?id=19218)
- remove test patch, no longer needed
- re-encode Credits as UTF-8
- include TODO as %%doc
- add buildreqs perl(Array::Compare), perl(MIME::Base64), perl(Sub::Uplevel),
  perl(Test::Exception), perl(Test::NoWarnings), perl(Test::Pod),
  perl(Test::Warn), perl(Tree::DAG_Node)
- add patch needed to disable testsuite non-interactively
- run test suite but disable external tests by default; external tests can be
  enabled by using rpmbuild --with externaltests
- add patch to change hosts connected to in external tests

* Fri Nov 16 2007 Parag Nemade <panemade@gmail.com> - 1.30-7
- Merge Review (#226272) Spec cleanup

* Tue Nov  6 2007 Stepan Kasal <skasal@redhat.com> - 1.30-6
- fix a typo in description (#231756, #231757)

* Tue Oct 16 2007 Tom "spot" Callaway <tcallawa@redhat.com> - 1.30-5.1
- correct license tag
- add BR: perl(ExtUtils::MakeMaker)

* Tue Aug 21 2007 Warren Togami <wtogami@redhat.com> - 1.30-5
- rebuild

* Fri Jul 14 2006 Warren Togami <wtogami@redhat.com> - 1.30-4
- import into FC6

* Tue Feb 28 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.30-3
- Rebuild for FC5 (perl 5.8.8).

* Fri Jan 27 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 1.30-2
- CVE-2005-0106: patch from Mandriva
  http://wwwnew.mandriva.com/security/advisories?name=MDKSA-2006:023

* Sun Jan 15 2006 Ville Skyttä <ville.skytta at iki.fi> - 1.30-1
- 1.30.
- Optionally run the test suite during build with "--with tests".

* Wed Nov  9 2005 Ville Skyttä <ville.skytta at iki.fi> - 1.26-3
- Rebuild for new OpenSSL.
- Cosmetic cleanups.

* Fri Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 1.26-2
- rebuilt

* Mon Dec 20 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.26-1
- Drop fedora.us release prefix and suffix.

* Mon Oct 25 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.26-0.fdr.2
- Convert manual page to UTF-8.

* Tue Oct 12 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.26-0.fdr.1
- Update to unofficial 1.26 from Peter Behroozi, adds get1_session(),
  enables session caching with IO::Socket::SSL (bug 1859, bug 1860).
- Bring outdated test14 up to date (bug 1859, test suite still not enabled).

* Sun Jul 11 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.25-0.fdr.4
- Rename to perl-Net-SSLeay, provide perl-Net_SSLeay for compatibility
  with the rest of the world.

* Wed Jul  7 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.25-0.fdr.3
- Bring up to date with current fedora.us Perl spec template.
- Include examples in docs.

* Sun Feb  8 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:1.25-0.fdr.2
- Reduce directory ownership bloat.

* Fri Oct 17 2003 Ville Skyttä <ville.skytta at iki.fi> - 0:1.25-0.fdr.1
- First build.
